=====================
Appendix C. Changelog
=====================
:Info: This is the changelog for rebookmaker.
:Author: Shlomi Fish <shlomif@cpan.org>
:Copyright: © 2020, Shlomi Fish.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2020-09-12
:Version: 0.8.1

.. index:: CHANGELOG

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/shlomif/rebookmaker/releases>`_.

Version History
===============

0.8.1
    Clarified the description of the project.

    Convert the build system to https://pypi.org/project/pydistman/
    which was extracted from the code of this and other projects.

0.8.0
    Improve the documentation: add links and explanations.
    Correct the spelling of the github username of "setanta".

0.6.0
    Set up a GitHub repo at https://pypi.org/project/rebookmaker/

    Add make_epub_from_data().

0.4.0
    Add and install the rebookmaker executable.

0.2.0
    Add the compression parameter to EbookMaker.

0.0.1
    Initial release.
